Name:           python-tabulate
Version:        0.8.5
Release:        1%{?dist}
Summary:        Pretty-print tabular data in Python, a library and a command-line utility

# SPDX
License:        MIT
URL:            https://github.com/astanin/python-tabulate
Source0:        %{pypi_source tabulate}
# Hand-written for Fedora based on --help output using groff_man(7) format
Source1:        tabulate.1

BuildArch:      noarch

BuildRequires:  python2-devel
BuildRequires:  python%{python3_pkgversion}-devel
BuildRequires:  python%{python3_other_pkgversion}-devel

# setup.py (with fallback to distutils)
BuildRequires:  python2-setuptools
BuildRequires:  python%{python3_pkgversion}-setuptools
BuildRequires:  python%{python3_other_pkgversion}-setuptools

# “widechars” extra (setup.py: extras_require)
BuildRequires:  python2-wcwidth
BuildRequires:  python%{python3_pkgversion}-wcwidth
# Not packaged in EPEL7:
# BuildRequires:  python%%{python3_other_pkgversion}-wcwidth

# Additional test dependencies
BuildRequires:  python2-nose
BuildRequires:  python%{python3_pkgversion}-nose
BuildRequires:  python%{python3_other_pkgversion}-nose
BuildRequires:  python2-numpy
BuildRequires:  python%{python3_pkgversion}-numpy
BuildRequires:  python%{python3_other_pkgversion}-numpy
BuildRequires:  python2-pandas
# Not packaged in EPEL7:
# BuildRequires:  python%%{python3_pkgversion}-pandas
# Not packaged in EPEL7:
# BuildRequires:  python%%{python3_other_pkgversion}-pandas

# We choose to use pytest instead of nose as the test runner.
BuildRequires:  python2-pytest
BuildRequires:  python%{python3_pkgversion}-pytest
BuildRequires:  python%{python3_other_pkgversion}-pytest

%global _description %{expand:
The main use cases of the library are:
• printing small tables without hassle: just one function call, formatting is
  guided by the data itself
• authoring tabular data for lightweight plain-text markup: multiple output
  formats suitable for further editing or transformation
• readable presentation of mixed textual and numeric data: smart column
  alignment, configurable number formatting, alignment by a decimal point}

%description %{_description}


%package -n python2-tabulate
Summary:        %{summary}

%{?python_provide:%python_provide python2-tabulate}

%description -n python2-tabulate %{_description}


%package -n python%{python3_pkgversion}-tabulate
Summary:        %{summary}

%{?python_provide:%python_provide python%{python3_pkgversion}-tabulate}

%description -n python%{python3_pkgversion}-tabulate %{_description}


%package -n python%{python3_other_pkgversion}-tabulate
Summary:        %{summary}

%{?python_provide:%python_provide python%{python3_other_pkgversion}-tabulate}

%description -n python%{python3_other_pkgversion}-tabulate %{_description}


%prep
%autosetup -n tabulate-%{version}
# Fix interpreter paths in CLI tests
sed -r -i 's@"python"@"%{python3}"@g' test/test_cli.py


%build
# mind the build chain of the unversioned executables
%py2_build
%py3_other_build
%py3_build


%install
%py2_install
%py3_other_install
# make sure the executables are owned by py3
find '%{buildroot}%{_bindir}' -type f -print -delete
%py3_install

install -d '%{buildroot}%{_mandir}/man1'
install -t '%{buildroot}%{_mandir}/man1' -m 0644 -p '%{SOURCE1}'


%check
# There are doctests, but the versions of pytest we have available lack the
# --doctest-modules option, so we skip running those.
PATH="${PATH}:%{buildroot}%{_bindir}" \
    PYTHONPATH='%{buildroot}%{python2_sitelib}' \
    PYTHONDONTWRITEBYTECODE=1 \
    %{python2} -m pytest --ignore benchmark.py
PATH="${PATH}:%{buildroot}%{_bindir}" \
    PYTHONPATH='%{buildroot}%{python3_sitelib}' \
    PYTHONDONTWRITEBYTECODE=1 \
    %{python3} -m pytest --ignore benchmark.py
PATH="${PATH}:%{buildroot}%{_bindir}" \
    PYTHONPATH='%{buildroot}%{python3_other_sitelib}' \
    PYTHONDONTWRITEBYTECODE=1 \
    %{python3_other} -m pytest --ignore benchmark.py


%files -n python2-tabulate
%license LICENSE
%doc CHANGELOG
%doc README.md

%{python2_sitelib}/tabulate-%{version}-py%{python2_version}.egg-info/
%{python2_sitelib}/tabulate.py
%{python2_sitelib}/tabulate.py?

# exclude unversioned binary to not confuse dependency check
%exclude %{_bindir}/tabulate


%files -n python%{python3_other_pkgversion}-tabulate
%license LICENSE
%doc CHANGELOG
%doc README.md

%{python3_other_sitelib}/tabulate-%{version}-py%{python3_other_version}.egg-info/
%{python3_other_sitelib}/tabulate.py
%{python3_other_sitelib}/__pycache__/tabulate.cpython-%{python3_other_version_nodots}.py?

# exclude unversioned binary to not confuse dependency check
%exclude %{_bindir}/tabulate


%files -n python%{python3_pkgversion}-tabulate
%license LICENSE
%doc CHANGELOG
%doc README.md

%{python3_sitelib}/tabulate-%{version}-py%{python3_version}.egg-info/
%pycached %{python3_sitelib}/tabulate.py

%{_bindir}/tabulate
%{_mandir}/man1/tabulate.1*


%changelog
* Sat Oct 29 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 0.8.5-1
- Update to 0.8.5 and add a man page

* Sat Oct 29 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 0.8.3-9
- Remove conditionals for non-EPEL7 branches
- Run the tests on all Python versions
- Many small packaging improvements

* Sun Sep 15 2019 Raphael Groner <projects.rg@smart.ms> - 0.8.3-8
- make sure the executables are owned by py3, rhbz#1750911

* Sat May 04 2019 Raphael Groner <projects.rg@smart.ms> - 0.8.3-7
- epel: (re-)add properly subpackages for python2 and both python3 versions
- use macro for description

* Thu Feb 21 2019 Raphael Groner <projects.rg@smart.ms> - 0.8.3-6
- fix merge conflicts

* Sat Feb 02 2019 Fedora Release Engineering <releng@fedoraproject.org> - 0.8.3-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_30_Mass_Rebuild

* Sat Jan 26 2019 Ankur Sinha <ankursinha AT fedoraproject DOT org> - 0.8.3-3
- Remove py2 subpackage

* Sat Jan 26 2019 Ankur Sinha <ankursinha AT fedoraproject DOT org> - 0.8.3-2
- Fix FTBFS

* Sat Jan 26 2019 Ankur Sinha <ankursinha AT fedoraproject DOT org> - 0.8.3-1
- Update to latest upstream release

* Sat Jul 14 2018 Fedora Release Engineering <releng@fedoraproject.org> - 0.8.2-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Tue Jun 19 2018 Miro Hrončok <mhroncok@redhat.com> - 0.8.2-3
- Rebuilt for Python 3.7

* Fri Feb 09 2018 Fedora Release Engineering <releng@fedoraproject.org> - 0.8.2-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Tue Jan 09 2018 Steve Traylen <steve.traylen@cern.ch> - 0.8.2-1
- Update to 0.8.2, Correct source URL.

* Tue Oct 03 2017 Igor Gnatenko <ignatenkobrain@fedoraproject.org> - 0.8.1-1
- Update to 0.8.1
- Run more tests

* Sun Oct 01 2017 Igor Gnatenko <ignatenkobrain@fedoraproject.org> - 0.8.0-1
- Update to 0.8.0

* Thu Jul 27 2017 Fedora Release Engineering <releng@fedoraproject.org> - 0.7.5-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Sat Feb 11 2017 Fedora Release Engineering <releng@fedoraproject.org> - 0.7.5-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Mon Dec 19 2016 Miro Hrončok <mhroncok@redhat.com> - 0.7.5-5
- Rebuild for Python 3.6

* Tue Jul 19 2016 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.7.5-4
- https://fedoraproject.org/wiki/Changes/Automatic_Provides_for_Python_RPM_Packages

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 0.7.5-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Sun Nov 29 2015 Igor Gnatenko <i.gnatenko.brain@gmail.com> - 0.7.5-2
- Drop multiple versions of bins

* Tue Nov 24 2015 Igor Gnatenko <i.gnatenko.brain@gmail.com> - 0.7.5-1
- Initial package
